cgexplore.terms.TargetAngle
===========================

.. currentmodule:: cgexplore.terms

.. autoclass:: TargetAngle
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~TargetAngle.human_readable
      ~TargetAngle.vector
      ~TargetAngle.vector_key
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TargetAngle.type1
      ~TargetAngle.type2
      ~TargetAngle.type3
      ~TargetAngle.element1
      ~TargetAngle.element2
      ~TargetAngle.element3
      ~TargetAngle.angle
      ~TargetAngle.angle_k
   
   